@@ -72,8 +72,15 @@ FOptionContainer::~FOptionContainer()
 void FOptionContainer::reset()
 {
     conffile.clear();
-    delete banned_page;
-    banned_page = NULL;
+    if (neterr_page != nullptr)
+    {
+        delete neterr_page;
+        neterr_page = nullptr;
+    }
+    if (banned_page != nullptr) {
+        delete banned_page;
+        banned_page = nullptr;
+    }
     resetJustListData();
 }
 
@@ -160,7 +167,7 @@ bool FOptionContainer::readConfFile(const char *filename) {
                 temp.removeWhiteSpace(); // get rid of spaces at end of line
                 // deal with included files
                 if (temp.startsWith(".")) {
-                    temp = temp.after(".include<").before(">");
+                    temp = temp.after(".Include<").before(">");
                     if (temp.length() > 0) {
                         if (!readConfFile(temp.toCharArray())) {
                             conffiles.close();
@@ -464,16 +471,16 @@ bool FOptionContainer::read(const char *filename) {
                     // HTML template file
                 }
             } else {  // if blank will default to HTML template file
-                neterr_template = o.languagepath + "template.html";
+                neterr_template = o.languagepath + "neterr_template.html";
                 neterr_page = new HTMLTemplate;
-                if (!(banned_page->readTemplateFile(neterr_template.toCharArray()))) {
+                if (!(neterr_page->readTemplateFile(neterr_template.toCharArray()))) {
                     if (!is_daemonised) {
                         std::cerr << thread_id << "Error reading default HTML and NetErr Template file: " << html_template << std::endl;
                     }
                     syslog(LOG_ERR, "Error reading default HTML and NetErr Template file: %s", html_template.toCharArray());
                     return false;
 	        }
-	    }
+	    } 
         }
 
         // override ssl default banned page
@@ -539,7 +546,6 @@ bool FOptionContainer::read(const char *filename) {
             if (!realitycheck(weighted_phrase_mode, 0, 3, "weightedphrasemode"))
                 return false;
         }
-
         std::string exception_phrase_list_location(findoptionS("exceptionphraselist"));
         std::string weighted_phrase_list_location(findoptionS("weightedphraselist"));
         std::string banned_phrase_list_location(findoptionS("bannedphraselist"));
@@ -559,7 +565,7 @@ bool FOptionContainer::read(const char *filename) {
             if (!o.lm.readbplfile(banned_phrase_list_location.c_str(),
                                   exception_phrase_list_location.c_str(),
                                   weighted_phrase_list_location.c_str(), banned_phrase_list,
-                                  force_quick_search)) {
+                                  force_quick_search, naughtyness_limit)) {
                 return false;
             } // read banned, exception, weighted phrase list
             banned_phrase_flag = true;
@@ -662,14 +668,25 @@ bool FOptionContainer::read(const char *filename) {
                         if (!o.lm.readbplfile(banned_searchterm_list_location.c_str(),
                                               exception_searchterm_list_location.c_str(),
                                               weighted_searchterm_list_location.c_str(), searchterm_list,
-                                              force_quick_search)) {
+                                              force_quick_search, naughtyness_limit)) {
                             return false;
                         }
                         searchterm_flag = true;
                     }
                 }
             }
-
+	    
+	std::string content_regexp_list_location(findoptionS("contentregexplist"));
+	if (content_regexp_list_location.length() > 1) {
+		unsigned int content_regexp_list;
+		if (!LMeta.readRegExReplacementFile(content_regexp_list_location.c_str(), "contentregexplist", content_regexp_list, content_regexp_list_rep, content_regexp_list_comp)) {
+             		return false;
+		} else {
+			content_regexp_flag = true;
+		} 
+	} else {
+			content_regexp_flag = false;
+	}
 
 #ifdef DGDEBUG
         std::cerr << thread_id << "Lists in memory" << std::endl;
