@@ -805,7 +805,7 @@ void HTTPHeader::dbshowheader(String *url, const char *clientip)
     } else {
         reqres = "REQ";
     }
-    std::hash<std::thread::id> htid;
+    //std::hash<std::thread::id> htid;
 //    std::thread::id tid = std::this_thread::get_id();
 //    std::size_t tid = htid(std::this_thread::get_id());
     const char *tid = thread_id.c_str();
@@ -981,14 +981,14 @@ void HTTPHeader::checkheader(bool allowpersistent)
     }
 }
 
-#ifdef DGDEBUG
     //if its http1.1
     bool onepointone = false;
     if (header.front().after("HTTP/").startsWith("1.1")) {
+#ifdef DGDEBUG
         std::cerr << thread_id << "CheckHeader: HTTP/1.1 detected" << " Line: " << __LINE__ << " Function: " << __func__ << std::endl;
+#endif
         onepointone = true;
     }
-#endif
 
     if (outgoing) {        // set request Type
         requesttype = header.front().before(" ");
@@ -1049,7 +1049,7 @@ void HTTPHeader::checkheader(bool allowpersistent)
               << " 1.1=" << onepointone << " connectionclose=" << connectionclose << " CL=" << (pcontentlength != NULL) << " Line: " << __LINE__ << " Function: " << __func__ << std::endl;
 #endif
 
-    if (connectionclose || (outgoing ? isconnect : (pcontentlength == NULL))) {
+    if (connectionclose || (!onepointone && (outgoing ? isconnect : (pcontentlength == NULL)))) {
         // couldnt have done persistency even if we wanted to
         allowpersistent = false;
     }
@@ -1895,6 +1895,10 @@ void HTTPHeader::setClientIP(String &ip) {
     s_clientip = ip.toCharArray();
 }
 
+String HTTPHeader::getClientIP() {
+	    return s_clientip;
+}
+
 void HTTPHeader::setDirect() {
     isdirect = true;
 }
