@@ -33,7 +33,6 @@ extern thread_local std::string thread_id;
 // IMPLEMENTATION
 
 OptionContainer::OptionContainer()
-    : use_filter_groups_list(false), stats_human_readable(false), auth_requires_user_and_group(false), use_group_names_list(false), auth_needs_proxy_query(false), prefer_cached_lists(false), e2_front_log(false), no_daemon(false), no_logger(false), log_syslog(false), anonymise_logs(false), log_ad_blocks(false), log_timestamp(false), log_user_agent(false), soft_restart(false), delete_downloaded_temp_files(false), max_logitem_length(2000), max_content_filter_size(0), max_content_ramcache_scan_size(0), max_content_filecache_scan_size(0), scan_clean_cache(0), content_scan_exceptions(0), initial_trickle_delay(0), trickle_delay(0), content_scanner_timeout(0), reporting_level(0), weighted_phrase_mode(0), numfg(0), dstat_log_flag(false), dstat_interval(300), dns_user_logging(false), LC_cnt(0), abort_on_missing_list(false), SB_trace(false), default_fg(0), default_trans_fg(0), default_icap_fg(0)
 {
     log_Q = new Queue<std::string>;
    // http_worker_Q = new Queue<LQ_rec>;
@@ -811,7 +810,7 @@ bool OptionContainer::read(std::string& filename, int type)
         }
 
         // map port numbers to auth plugin names
-        for (int i = 0; i < authplugins.size(); i++) {
+        for (unsigned int i = 0; i < authplugins.size(); i++) {
             AuthPlugin *tmpPlugin = (AuthPlugin *)authplugins[i];
             String tmpStr = tmpPlugin->getPluginName();
 
@@ -1371,6 +1370,12 @@ bool OptionContainer::loadAuthPlugins()
             auth_needs_proxy_query = true;
 #ifdef DGDEBUG
             std::cout << "Auth plugin relies on querying parent proxy" << std::endl;
+#endif
+        }
+        if (app->needs_proxy_access_in_plugin) {
+            auth_needs_proxy_in_plugin = true;
+#ifdef DGDEBUG
+            std::cout << "Auth plugin relies on querying parent proxy within plugin" << std::endl;
 #endif
         }
         authplugins.push_back(app);
