@@ -97,11 +97,9 @@ bool StoryBoard::readFile(const char *filename, ListMeta &LM, bool is_top) {
 #endif
         line = linebuffer.c_str();
         line.removeWhiteSpace();
-        if (caseinsensitive)
-            line.toLower();
         // handle included list files
         if (line.startsWith(".")) {
-            temp = line.after(".include<").before(">");
+            temp = line.after(".Include<").before(">");
             if (temp.length() > 0) {
                 if (!readFile(temp.toCharArray(), *LMeta, false)) {
                     listfile.close();
@@ -114,6 +112,8 @@ bool StoryBoard::readFile(const char *filename, ListMeta &LM, bool is_top) {
             }
         }
         if (line.startsWith("#")) continue;   // ignore comment lines
+        if (caseinsensitive)
+            line.toLower();
         command = line.before("(");
         command.removeWhiteSpace();
         params = line.before(")").after("(");
@@ -880,7 +880,8 @@ std::deque<url_rec> StoryBoard::ipToHostname(NaughtyFilter &cm) {
     std::deque<url_rec> result;
     const char *ip = cm.urldomain.c_str();
     String urlp = cm.urld.after("/");
-    struct in_addr address, **addrptr;
+    //struct in_addr address, **addrptr;
+    struct in_addr address;
     if (inet_aton(ip, &address)) { // convert to in_addr
         struct hostent *answer;
         answer = gethostbyaddr((char *) &address, sizeof(address), AF_INET);
