@@ -133,8 +133,14 @@ int icapinstance::init(void *args)
     }
     icapip = inet_ntoa(*(struct in_addr *)host->h_addr_list[0]);
 
-#ifdef DGDEBUG
-    std::cerr << thread_id << "ICAP server address:" << icapip << std::endl;
+#ifndef NEWDEBUG_OFF
+        if(o.myDebug->ICAPC)
+        {
+            std::ostringstream oss (std::ostringstream::out);
+            oss << thread_id << "ICAP server is " << icapip << std::endl;
+            o.myDebug->Debug("ICAPC",oss.str());
+            std::cerr << thread_id << "ICAP server is " << icapip << std::endl;
+        }
 #endif
 
     // try to connect to the ICAP server and perform an OPTIONS request
@@ -150,10 +156,17 @@ int icapinstance::init(void *args)
         // first line - look for 200 OK
         icapsock.getLine(buff, 8192, o.content_scanner_timeout);
         line = buff;
-#ifdef DGDEBUG
-        std::cerr << thread_id << "ICAP/1.0 OPTIONS response:" << std::endl
-                  << line << std::endl;
+
+#ifndef NEWDEBUG_OFF
+        if(o.myDebug->ICAPC)
+        {
+            std::ostringstream oss (std::ostringstream::out);
+            oss << thread_id << "ICAP/1.0 OPTIONS response: " << line << std::endl;
+            o.myDebug->Debug("ICAPC",oss.str());
+            std::cerr << thread_id << "ICAP/1.0 OPTIONS response: " << line << std::endl;
+        }
 #endif
+
         if (line.after(" ").before(" ") != "200") {
             if (!is_daemonised)
                 std::cerr << thread_id << "ICAP response not 200 OK" << std::endl;
@@ -163,18 +176,31 @@ int icapinstance::init(void *args)
         }
         while (icapsock.getLine(buff, 8192, o.content_scanner_timeout) > 0) {
             line = buff;
-#ifdef DGDEBUG
-            std::cerr << thread_id << line << std::endl;
+
+#ifndef NEWDEBUG_OFF
+	if(o.myDebug->ICAPC)
+        {
+            std::ostringstream oss (std::ostringstream::out);
+            oss << thread_id << "ICAP/1.0 OPTIONS response part: " << line << std::endl;
+            o.myDebug->Debug("ICAPC",oss.str());
+            std::cerr << thread_id << "ICAP/1.0 OPTIONS response part: " << line << std::endl;
+        }
 #endif
-            if (line.startsWith("\r")) {
+
+  	    if (line.startsWith("\r")) {
                 break;
             } else if (line.startsWith("Preview:")) {
-                usepreviews = true;
-                previewsize = line.after(": ").toInteger();
+              previewsize = line.after(": ").toInteger();
+	      if (previewsize > 0)
+	      	usepreviews = true;
             } else if (line.startsWith("Server:")) {
                 if (line.contains("AntiVir-WebGate")) {
                     needsBody = true;
                 }
+            } else if (line.startsWith("Service-ID:")) {
+                if (line.contains("KAVIcap")) {
+                    needsBody = true;
+                }
             } else if (line.startsWith("X-Allow-Out:")) {
                 if (line.contains("X-Infection-Found")) {
                     supportsXIF = true;
@@ -188,12 +214,24 @@ int icapinstance::init(void *args)
         syslog(LOG_ERR, "ICAP server did not respond to OPTIONS request: %s", e.what());
         return DGCS_ERROR;
     }
-#ifdef DGDEBUG
-    if (usepreviews)
-        std::cerr << thread_id << "Message previews enabled; size: " << previewsize << std::endl;
-    else
-        std::cerr << thread_id << "Message previews disabled" << std::endl;
+
+#ifndef NEWDEBUG_OFF
+        if(o.myDebug->ICAPC)
+        {       
+    	    if (usepreviews){
+            	std::ostringstream oss (std::ostringstream::out);
+            	oss << thread_id << "Message previews enabled; size: " << previewsize << std::endl;
+            	o.myDebug->Debug("ICAPC",oss.str());
+            	std::cerr << thread_id << "Message previews enabled; size: " << previewsize << std::endl;
+	    } else {
+	        std::ostringstream oss (std::ostringstream::out);
+                oss << thread_id << "Message previews enabled; size: disabled" << std::endl;
+                o.myDebug->Debug("ICAPC",oss.str());
+                std::cerr << thread_id << "Message previews enabled; size: disabled" << std::endl;
+	    }	
+        }
 #endif
+
     return DGCS_OK;
 }
 
@@ -210,11 +248,19 @@ int icapinstance::scanMemory(HTTPHeader *requestheader, HTTPHeader *docheader, c
         icapsock.close();
         return DGCS_SCANERROR;
     }
-#ifdef DGDEBUG
-    std::cerr << thread_id << "About to send memory data to icap" << std::endl;
-    if (usepreviews && (objectsize > previewsize))
-        std::cerr << thread_id << "Sending preview first" << std::endl;
+
+#ifndef NEWDEBUG_OFF
+    if(o.myDebug->ICAPC)
+       {
+	   if (usepreviews && (objectsize > previewsize)){
+            	std::ostringstream oss (std::ostringstream::out);
+            	oss << thread_id << "Sending memory date to icap preview first" << std::endl;
+            	o.myDebug->Debug("ICAPC",oss.str());
+            	std::cerr << thread_id << "Sending memory date to icap preview first" << std::endl;
+	   }	
+    	}
 #endif
+
     unsigned int sent = 0;
     if (usepreviews && (objectsize > previewsize)) {
         try {
@@ -236,10 +282,17 @@ int icapinstance::scanMemory(HTTPHeader *requestheader, HTTPHeader *docheader, c
             snprintf(objectsizehex, sizeof(objectsizehex), "%x\r\n", objectsize - previewsize);
             icapsock.writeString(objectsizehex);
         } catch (std::exception &e) {
-#ifdef DGDEBUG
+
+#ifndef NEWDEBUG_OFF
+        if(o.myDebug->ICAPC)
+        {
+            std::ostringstream oss (std::ostringstream::out);
+            oss << thread_id << "Exception sending message preview to ICAP: " << e.what() << std::endl;
+            o.myDebug->Debug("ICAPC",oss.str());
             std::cerr << thread_id << "Exception sending message preview to ICAP: " << e.what() << std::endl;
+        }
 #endif
-            // this *might* just be an early response & closed connection
+	    // this *might* just be an early response & closed connection
             if (icapsock.checkForInput()) {
                 int rc = doScan(icapsock, docheader, object, objectsize, checkme);
                 if (rc != ICAP_NODATA)
@@ -253,18 +306,41 @@ int icapinstance::scanMemory(HTTPHeader *requestheader, HTTPHeader *docheader, c
     }
     try {
         if(icapsock.writeToSocket(object + sent, objectsize - sent, 0, o.content_scanner_timeout)) {
-#ifdef DGDEBUG
-            std::cerr << thread_id << "total sent to icap: " << objectsize << std::endl;
-#endif
-            icapsock.writeString("\r\n0\r\n\r\n"); // end marker
-#ifdef DGDEBUG
-            std::cerr << thread_id << "memory was sent to icap" << std::endl;
-#endif
+
+#ifndef NEWDEBUG_OFF
+        if(o.myDebug->ICAPC)
+        {
+            std::ostringstream oss (std::ostringstream::out);
+            oss << thread_id << "total sent to icap: " << objectsize << std::endl;
+            o.myDebug->Debug("ICAPC",oss.str());
+            std::cerr << thread_id << "total sent to icap: " << objectsize << std::endl; 
         }
-    } catch (std::exception &e) {
-#ifdef DGDEBUG
-        std::cerr << thread_id << "Exception sending memory file to ICAP: " << e.what() << std::endl;
 #endif
+
+	    icapsock.writeString("\r\n0\r\n\r\n"); // end marker
+#ifndef NEWDEBUG_OFF
+        if(o.myDebug->ICAPC)
+        {
+            std::ostringstream oss (std::ostringstream::out);
+            oss << thread_id << "memory was sent to icap" << std::endl;
+            o.myDebug->Debug("ICAPC",oss.str());
+            std::cerr << thread_id << "memory was sent to icap" << std::endl; 
+        }
+#endif
+
+	}
+    } catch (std::exception &e) {
+
+#ifndef NEWDEBUG_OFF
+        if(o.myDebug->ICAPC)
+        {
+            std::ostringstream oss (std::ostringstream::out);
+            oss << thread_id << "Exception sending memory file to ICAP: " << e.what() << std::endl;
+            o.myDebug->Debug("ICAPC",oss.str());
+            std::cerr << thread_id << "Exception sending memory file to ICAP: " << e.what() << std::endl;
+        }
+#endif
+
         // this *might* just be an early response & closed connection
         if (icapsock.checkForInput()) {
             int rc = doScan(icapsock, docheader, object, objectsize, checkme);
@@ -288,10 +364,18 @@ int icapinstance::scanFile(HTTPHeader *requestheader, HTTPHeader *docheader, con
     lastmessage = lastvirusname = "";
     int filefd = open(filename, O_RDONLY);
     if (filefd < 0) {
-#ifdef DGDEBUG
-        std::cerr << thread_id << "Error opening file (" << filename << "): " << strerror(errno) << std::endl;
+
+#ifndef NEWDEBUG_OFF
+        if(o.myDebug->ICAPC)
+        {
+            std::ostringstream oss (std::ostringstream::out);
+            oss << thread_id << "Error opening file (" << filename << "): " << strerror(errno) << std::endl;
+            o.myDebug->Debug("ICAPC",oss.str());
+            std::cerr << thread_id << "Error opening file (" << filename << "): " << strerror(errno) << std::endl;
+        }
 #endif
-        lastmessage = "Error opening file to send to ICAP";
+
+	lastmessage = "Error opening file to send to ICAP";
         syslog(LOG_ERR, "Error opening file to send to ICAP: %s", strerror(errno));
         return DGCS_SCANERROR;
     }
@@ -311,11 +395,16 @@ int icapinstance::scanFile(HTTPHeader *requestheader, HTTPHeader *docheader, con
     char *object = new char[100];
     int objectsize = 0;
 
-#ifdef DGDEBUG
-    std::cerr << thread_id << "About to send file data to icap" << std::endl;
-    if (usepreviews && (filesize > previewsize))
-        std::cerr << thread_id << "Sending preview first" << std::endl;
+#ifndef NEWDEBUG_OFF
+        if(o.myDebug->ICAPC)
+        {
+            std::ostringstream oss (std::ostringstream::out);
+            oss << thread_id << "About to send file data to icap" << std::endl;
+            o.myDebug->Debug("ICAPC",oss.str());
+            std::cerr << thread_id << "About to send file data to icap" << std::endl;
+        }
 #endif
+
     if (usepreviews && (filesize > previewsize)) {
         try {
             while (sent < previewsize) {
@@ -353,10 +442,17 @@ int icapinstance::scanFile(HTTPHeader *requestheader, HTTPHeader *docheader, con
             snprintf(objectsizehex, sizeof(objectsizehex), "%x\r\n", filesize - previewsize);
             icapsock.writeString(objectsizehex);
         } catch (std::exception &e) {
-#ifdef DGDEBUG
+
+#ifndef NEWDEBUG_OFF
+        if(o.myDebug->ICAPC)
+        {
+            std::ostringstream oss (std::ostringstream::out);
+            oss << thread_id << "Exception sending message preview to ICAP: " << e.what() << std::endl;
+            o.myDebug->Debug("ICAPC",oss.str());
             std::cerr << thread_id << "Exception sending message preview to ICAP: " << e.what() << std::endl;
+        }
 #endif
-            icapsock.close();
+	    icapsock.close();
             lastmessage = "Exception sending message preview to ICAP";
             syslog(LOG_ERR, "Exception sending message preview to ICAP: %s", e.what());
             delete[] data;
@@ -377,19 +473,43 @@ int icapinstance::scanFile(HTTPHeader *requestheader, HTTPHeader *docheader, con
     try {
         while (sent < filesize) {
             int rc = readEINTR(filefd, data, 256 * 1024);
-#ifdef DGDEBUG
+
+#ifndef NEWDEBUG_OFF
+        if(o.myDebug->ICAPC)
+        {
+            std::ostringstream oss (std::ostringstream::out);
+            oss << thread_id << "reading icap file rc: " << rc << std::endl;
+            o.myDebug->Debug("ICAPC",oss.str());
             std::cerr << thread_id << "reading icap file rc: " << rc << std::endl;
+        }
 #endif
+
             if (rc < 0) {
-#ifdef DGDEBUG
-                std::cerr << thread_id << "error reading icap file so throwing exception" << std::endl;
+
+#ifndef NEWDEBUG_OFF
+		if(o.myDebug->ICAPC)
+        	{
+			std::ostringstream oss (std::ostringstream::out);
+            		oss << thread_id << "error reading icap file so throwing exception" << std::endl;
+            		o.myDebug->Debug("ICAPC",oss.str());
+            		std::cerr << thread_id << "error reading icap file so throwing exception" << std::endl;
+        	}	
 #endif
+
                 throw std::runtime_error("could not read from file");
             }
             if (rc == 0) {
-#ifdef DGDEBUG
-                std::cerr << thread_id << "got zero bytes reading icap file" << std::endl;
+
+#ifndef NEWDEBUG_OFF
+                if(o.myDebug->ICAPC)
+                {
+                        std::ostringstream oss (std::ostringstream::out);
+                        oss << thread_id << "got zero bytes reading icap file" << std::endl;
+                        o.myDebug->Debug("ICAPC",oss.str());
+                        std::cerr << thread_id << "got zero bytes reading icap file" << std::endl;
+                }
 #endif
+
                 break; // should never happen
             }
             memcpy(object + objectsize, data, (rc > (100 - objectsize)) ? (100 - objectsize) : rc);
@@ -399,16 +519,39 @@ int icapinstance::scanFile(HTTPHeader *requestheader, HTTPHeader *docheader, con
             };
             sent += rc;
         }
-#ifdef DGDEBUG
-        std::cerr << thread_id << "total sent to icap: " << sent << std::endl;
+
+#ifndef NEWDEBUG_OFF
+        if(o.myDebug->ICAPC)
+        {
+	        std::ostringstream oss (std::ostringstream::out);
+                oss << thread_id << "total sent to icap: " << sent << std::endl;
+                o.myDebug->Debug("ICAPC",oss.str());
+                std::cerr << thread_id << "total sent to icap: " << sent << std::endl;
+        }
 #endif
+
         icapsock.writeString("\r\n0\r\n\r\n"); // end marker
-#ifdef DGDEBUG
-        std::cerr << thread_id << "file was sent to icap" << std::endl;
+
+#ifndef NEWDEBUG_OFF
+        if(o.myDebug->ICAPC)
+        {
+                std::ostringstream oss (std::ostringstream::out);
+                oss << thread_id << "file was sent to icap" << std::endl;
+                o.myDebug->Debug("ICAPC",oss.str());
+                std::cerr << thread_id << "file was sent to icap" << std::endl;
+        }
 #endif
+
     } catch (std::exception &e) {
-#ifdef DGDEBUG
-        std::cerr << thread_id << "Exception sending file to ICAP: " << e.what() << std::endl;
+
+#ifndef NEWDEBUG_OFF
+        if(o.myDebug->ICAPC)
+        {
+                std::ostringstream oss (std::ostringstream::out);
+                oss << thread_id << "Exception sending file to ICAP: " << e.what() << std::endl;
+                o.myDebug->Debug("ICAPC",oss.str());
+                std::cerr << thread_id << "Exception sending file to ICAP: " << e.what() << std::endl;
+        }
 #endif
         lastmessage = "Exception sending file to ICAP";
         syslog(LOG_ERR, "Exception sending file to ICAP: %s", e.what());
@@ -432,10 +575,18 @@ bool icapinstance::doHeaders(Socket &icapsock, HTTPHeader *reqheader, HTTPHeader
 {
     int rc = icapsock.connect(icapip.toCharArray(), icapport);
     if (rc) {
-#ifdef DGDEBUG
-        std::cerr << thread_id << "Error connecting to ICAP server" << std::endl;
+
+#ifndef NEWDEBUG_OFF
+        if(o.myDebug->ICAPC)
+        {
+                std::ostringstream oss (std::ostringstream::out);
+                oss << thread_id << "Error connecting to ICAP server" << std::endl;
+                o.myDebug->Debug("ICAPC",oss.str());
+                std::cerr << thread_id << "Error connecting to ICAP server" << std::endl;
+        }
 #endif
-        lastmessage = "Error connecting to ICAP server";
+
+	lastmessage = "Error connecting to ICAP server";
         syslog(LOG_ERR, "Error connecting to ICAP server");
         return false;
     }
@@ -466,19 +617,34 @@ bool icapinstance::doHeaders(Socket &icapsock, HTTPHeader *reqheader, HTTPHeader
     }
     icapheader += "\r\n\r\n";
 
-#ifdef DGDEBUG
-    std::cerr << thread_id << "About to send icapheader:\n" << icapheader << encapsulatedheader << httpresponseheader << objectsizehex << std::endl;
+#ifndef NEWDEBUG_OFF
+        if(o.myDebug->ICAPC)
+        {
+                std::ostringstream oss (std::ostringstream::out);
+                oss << thread_id << "About to send icapheader:\n" << icapheader << encapsulatedheader << httpresponseheader << objectsizehex << std::endl;
+                o.myDebug->Debug("ICAPC",oss.str());
+                std::cerr << thread_id << "About to send icapheader:\n" << icapheader << encapsulatedheader << httpresponseheader << objectsizehex << std::endl;
+        }
 #endif
+
     try {
         icapsock.writeString(icapheader.toCharArray());
         icapsock.writeString(encapsulatedheader.toCharArray());
         icapsock.writeString(httpresponseheader.toCharArray());
         icapsock.writeString(objectsizehex);
     } catch (std::exception &e) {
-#ifdef DGDEBUG
-        std::cerr << thread_id << "Exception sending headers to ICAP: " << e.what() << std::endl;
+
+#ifndef NEWDEBUG_OFF
+        if(o.myDebug->ICAPC)
+        {
+                std::ostringstream oss (std::ostringstream::out);
+                oss << thread_id << "Exception sending headers to ICAP: " << e.what() << std::endl;
+                o.myDebug->Debug("ICAPC",oss.str());
+                std::cerr << thread_id << "Exception sending headers to ICAP: " << e.what()<< std::endl;
+        }
 #endif
-        lastmessage = "Exception sending headers to ICAP";
+
+	lastmessage = "Exception sending headers to ICAP";
         syslog(LOG_ERR, "Exception sending headers to ICAP: %s", e.what());
         return false;
     }
@@ -495,24 +661,47 @@ int icapinstance::doScan(Socket &icapsock, HTTPHeader *docheader, const char *ob
         if (rc == 0)
             return ICAP_NODATA;
         line = data;
-#ifdef DGDEBUG
-        std::cerr << thread_id << "reply from icap: " << line << std::endl;
+
+#ifndef NEWDEBUG_OFF
+        if(o.myDebug->ICAPC)
+        {
+                std::ostringstream oss (std::ostringstream::out);
+                oss << thread_id << "reply from icap: " << line << std::endl;
+                o.myDebug->Debug("ICAPC",oss.str());
+                std::cerr << thread_id << "reply from icap: " << line << std::endl;
+        }
 #endif
-        // reply is of the format:
+
+	// reply is of the format:
         // ICAP/1.0 204 No Content Necessary (etc)
 
         String returncode(line.after(" ").before(" "));
 
         if (returncode == "204") {
-#ifdef DGDEBUG
-            std::cerr << thread_id << "ICAP says clean!" << std::endl;
+
+#ifndef NEWDEBUG_OFF
+           if(o.myDebug->ICAPC)
+           {
+               	std::ostringstream oss (std::ostringstream::out);
+               	oss << thread_id << "ICAP says clean!" << std::endl;
+               	o.myDebug->Debug("ICAPC",oss.str());
+               	std::cerr << thread_id << "ICAP says clean!" << std::endl;
+           }
 #endif
-            delete[] data;
-            return DGCS_CLEAN;
+	   delete[] data;
+           return DGCS_CLEAN;
         } else if (returncode == "100") {
-#ifdef DGDEBUG
-            std::cerr << thread_id << "ICAP says continue!" << std::endl;
+
+#ifndef NEWDEBUG_OFF
+            if(o.myDebug->ICAPC)
+            {
+                std::ostringstream oss (std::ostringstream::out);
+                oss << thread_id << "ICAP says continue!" << std::endl;
+                o.myDebug->Debug("ICAPC",oss.str());
+                std::cerr << thread_id << "ICAP says continue!" << std::endl;
+            }
 #endif
+
             // discard rest of headers (usually just a blank line)
             // this is so we are in the right place in the data stream to
             // call doScan() again later, because people like Symantec seem
@@ -525,26 +714,40 @@ int icapinstance::doScan(Socket &icapsock, HTTPHeader *docheader, const char *ob
             delete[] data;
             return ICAP_CONTINUE;
         } else if (returncode == "200") {
-#ifdef DGDEBUG
-            std::cerr << thread_id << "ICAP says maybe not clean!" << std::endl;
+
+#ifndef NEWDEBUG_OFF
+            if(o.myDebug->ICAPC)
+            {
+                std::ostringstream oss (std::ostringstream::out);
+                oss << thread_id << "ICAP says maybe not clean!" << std::endl;
+                o.myDebug->Debug("ICAPC",oss.str());
+                std::cerr << thread_id << "ICAP says maybe not clean!" << std::endl;
+            }
 #endif
-            while (icapsock.getLine(data, 8192, o.content_scanner_timeout) > 0) {
+
+	    while (icapsock.getLine(data, 8192, o.content_scanner_timeout) > 0) {
                 if (data[0] == 13) // end marker
                     break;
                 line = data;
                 // Symantec's engine gives us the virus name in the ICAP headers
                 if (supportsXIF && line.startsWith("X-Infection-Found")) {
-#ifdef DGDEBUG
-                    std::cerr << thread_id << "ICAP says infected! (X-Infection-Found)" << std::endl;
+#ifndef NEWDEBUG_OFF
+            	if(o.myDebug->ICAPC)
+            	{
+                	std::ostringstream oss (std::ostringstream::out);
+                	oss << thread_id << "ICAP says infected! (X-Infection-Found)" << std::endl;
+                	o.myDebug->Debug("ICAPC",oss.str());
+                	std::cerr << thread_id << "ICAP says infected! (X-Infection-Found)" << std::endl;
+            	}
 #endif
-                    lastvirusname = line.after("Threat=").before(";");
+		    lastvirusname = line.after("Threat=").before(";");
                     delete[] data;
 
                     blockFile(NULL, NULL, checkme);
                     return DGCS_INFECTED;
                 }
             }
-            // AVIRA's Antivir gives us 200 in all cases, so
+            // AVIRA's and KAV Antivir gives us 200 in all cases, so
             // - unfortunately - we must pay attention to the encapsulated
             // header/body.
             if (needsBody) {
@@ -552,17 +755,35 @@ int icapinstance::doScan(Socket &icapsock, HTTPHeader *docheader, const char *ob
                 // if it's been modified, assume there's an infection
                 icapsock.getLine(data, 8192, o.content_scanner_timeout);
                 line = data;
-#ifdef DGDEBUG
-                std::cerr << thread_id << "Comparing original return code to modified:" << std::endl
+
+#ifndef NEWDEBUG_OFF
+                if(o.myDebug->ICAPC)
+                {
+                        std::ostringstream oss (std::ostringstream::out);
+                        oss << thread_id << "Comparing original return code to modified:" 
                           << docheader->header.front() << std::endl
                           << line << std::endl;
+                        o.myDebug->Debug("ICAPC",oss.str());
+                        std::cerr << thread_id <<  "Comparing original return code to modified:" 
+                          << docheader->header.front() << std::endl
+                          << line << std::endl;
+                }
 #endif
-                int respmodReturnCode = line.after(" ").before(" ").toInteger();
+
+		int respmodReturnCode = line.after(" ").before(" ").toInteger();
                 if (respmodReturnCode != docheader->returnCode()) {
-#ifdef DGDEBUG
-                    std::cerr << thread_id << "ICAP says infected! (returned header comparison)" << std::endl;
+
+#ifndef NEWDEBUG_OFF
+	            if(o.myDebug->ICAPC)
+        	    {
+                        std::ostringstream oss (std::ostringstream::out);
+                       	oss << thread_id << "ICAP says infected! (returned header comparison)" << std::endl;
+                       	o.myDebug->Debug("ICAPC",oss.str());
+                       	std::cerr << thread_id << "ICAP says infected! (returned header comparison)" << std::endl;
+                    }
 #endif
-                    delete[] data;
+
+		    delete[] data;
                     lastvirusname = "Unknown";
 
                     blockFile(NULL, NULL, checkme);
@@ -575,11 +796,19 @@ int icapinstance::doScan(Socket &icapsock, HTTPHeader *docheader, const char *ob
                         break;
                 }
 // grab body chunk size
-#ifdef DGDEBUG
-                std::cerr << thread_id << "Comparing original body data to modified" << std::endl;
-#endif
-                icapsock.getLine(data, 8192, o.content_scanner_timeout);
+		icapsock.getLine(data, 8192, o.content_scanner_timeout);
                 line = data;
+
+#ifndef NEWDEBUG_OFF
+                if(o.myDebug->ICAPC)
+                {
+                   std::ostringstream oss (std::ostringstream::out);
+                   oss << thread_id << "Comparing original body data to modified" << std::endl;
+                   o.myDebug->Debug("ICAPC",oss.str());
+                   std::cerr << thread_id << "Comparing original body data to modified" << std::endl;
+                }
+#endif
+
                 int bodysize = line.hexToInteger();
                 // get, say, the first 100 bytes and compare them to what we
                 // originally sent to see if it has been modified
@@ -588,16 +817,32 @@ int icapinstance::doScan(Socket &icapsock, HTTPHeader *docheader, const char *ob
                     chunksize = objectsize;
                 icapsock.readFromSocket(data, chunksize, 0, o.content_scanner_timeout);
                 if (memcmp(data, object, chunksize) == 0) {
-#ifdef DGDEBUG
-                    std::cerr << thread_id << "ICAP says clean!" << std::endl;
+
+#ifndef NEWDEBUG_OFF
+                if(o.myDebug->ICAPC)
+                {
+                   std::ostringstream oss (std::ostringstream::out); 
+                   oss << thread_id << "ICAP says clean! (body byte comparison)" << std::endl;
+                   o.myDebug->Debug("ICAPC",oss.str()); 
+                   std::cerr << thread_id << "ICAP says clean! (body byte comparison)" << std::endl;
+                }
 #endif
+
                     delete[] data;
                     return DGCS_CLEAN;
                 } else {
-#ifdef DGDEBUG
-                    std::cerr << thread_id << "ICAP says infected! (body byte comparison)" << std::endl;
+
+#ifndef NEWDEBUG_OFF
+                    if(o.myDebug->ICAPC)
+                    {
+                   	std::ostringstream oss (std::ostringstream::out);
+                   	oss << thread_id << "ICAP says infected! (body byte comparison)" << std::endl;
+                   	o.myDebug->Debug("ICAPC",oss.str());
+                   	std::cerr << thread_id << "ICAP says infected! (body byte comparison)" << std::endl;
+                    }
 #endif
-                    delete[] data;
+
+		    delete[] data;
                     lastvirusname = "Unknown";
 
                     blockFile(NULL, NULL, checkme);
@@ -606,36 +851,69 @@ int icapinstance::doScan(Socket &icapsock, HTTPHeader *docheader, const char *ob
             }
 // even if we don't find an X-Infection-Found header,
 // the file is still infected!
-#ifdef DGDEBUG
-            std::cerr << thread_id << "ICAP says infected! (no further tests)" << std::endl;
+
+#ifndef NEWDEBUG_OFF
+             if(o.myDebug->ICAPC)
+             {
+              	std::ostringstream oss (std::ostringstream::out);
+                oss << thread_id << "ICAP says infected! (no further tests)" << std::endl;
+                o.myDebug->Debug("ICAPC",oss.str());
+            	std::cerr << thread_id << "ICAP says infected! (no further tests)" << std::endl;
+            }
 #endif
-            delete[] data;
+
+	    delete[] data;
             lastvirusname = "Unknown";
 
             blockFile(NULL, NULL, checkme);
             return DGCS_INFECTED;
         } else if (returncode == "404") {
-#ifdef DGDEBUG
-            std::cerr << thread_id << "ICAP says no such service!" << std::endl;
+
+#ifndef NEWDEBUG_OFF
+           if(o.myDebug->ICAPC)
+           {
+           	std::ostringstream oss (std::ostringstream::out);
+                oss << thread_id << "ICAP says no such service!" << std::endl;
+                o.myDebug->Debug("ICAPC",oss.str());
+                std::cerr << thread_id << "ICAP says no such service!" << std::endl;
+           }
 #endif
-            lastmessage = "ICAP reports no such service";
+
+	    lastmessage = "ICAP reports no such service";
             syslog(LOG_ERR, "ICAP reports no such service; check your server URL");
             delete[] data;
             return DGCS_SCANERROR;
         } else {
-#ifdef DGDEBUG
-            std::cerr << thread_id << "ICAP returned unrecognised response code: " << returncode << std::endl;
+
+#ifndef NEWDEBUG_OFF
+           if(o.myDebug->ICAPC)
+           {
+           	std::ostringstream oss (std::ostringstream::out);
+                oss << thread_id << "ICAP returned unrecognised response code: " << returncode << std::endl;
+                o.myDebug->Debug("ICAPC",oss.str());
+                std::cerr << thread_id << "ICAP returned unrecognised response code: " << returncode << std::endl;
+           }
 #endif
-            lastmessage = "ICAP returned unrecognised response code.";
+
+	    lastmessage = "ICAP returned unrecognised response code.";
             syslog(LOG_ERR, "ICAP returned unrecognised response code: %s", returncode.toCharArray());
             delete[] data;
             return DGCS_SCANERROR;
         }
         delete[] data;
     } catch (std::exception &e) {
-#ifdef DGDEBUG
-        std::cerr << thread_id << "Exception getting reply from ICAP: " << e.what() << std::endl;
+
+#ifndef NEWDEBUG_OFF
+         if(o.myDebug->ICAPC)
+         {
+         	std::ostringstream oss (std::ostringstream::out);
+                oss << thread_id << "Exception getting reply from ICAP: " << e.what() << std::endl;
+                o.myDebug->Debug("ICAPC",oss.str());
+                std::cerr << thread_id << "Exception getting reply from ICAP: " << e.what() << std::endl;
+        }
 #endif
+
+
         lastmessage = "Exception getting reply from ICAP.";
         syslog(LOG_ERR, "Exception getting reply from ICAP: %s", e.what());
         delete[] data;
